@@ -18,7 +18,7 @@
     if (prod(mfrow)<nvar) par(ask=TRUE)
     # modif lundi, dcembre 16, 2002 at 16:48 
     # suite  message d'Alain Guerreau  
-    for (i in 1:(nvar)) s.class(x$li, oritab[, i], xax=xax, yax=yax, clab = 1.5, 
+    for (i in 1:(nvar)) s.class(x$li, oritab[, i], xax=xax, yax=yax, clabel = 1.5, 
         sub = names(oritab)[i], csub = csub, possub = possub, 
-        cgrid = 0, csta = 0, ...)
+        cgrid = 0, cstar = 0, ...)
 }
